#
# spec file for package popeye
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           popeye
Version:        0.22.1
Release:        1.1
Summary:        A Kubernetes cluster resource sanitizer
License:        Apache-2.0
URL:            https://github.com/derailed/popeye
Source:         popeye-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.17

%description
Pluto is a utility to help users find deprecated Kubernetes apiVersions in
their code repositories and their helm releases.
Popeye is a utility that scans live Kubernetes cluster and reports potential
issues with deployed resources and configurations. It sanitizes your cluster
based on what's deployed and not what's sitting on disk. By scanning your
cluster, it detects misconfigurations and helps you to ensure that best
practices are in place, thus preventing future headaches. It aims at reducing
the cognitive overload one faces when operating a Kubernetes cluster in the
wild. Furthermore, if your cluster employs a metric-server, it reports
potential resources over/under allocations and attempts to warn you should your
cluster run out of capacity.
Popeye is a readonly tool, it does not alter any of your Kubernetes resources
in any way!

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -ldflags="-X main.Version=%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.22.1:
  * rel v0.22.1
  * fix#425
  * update krew gha
* Mon Jan 27 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.22.0:
  * remove aws v1 deps
  * rel notes
  * update aws s3 to v2 + add minio support
  * update deps
  * update docs
* Sun Jan 26 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.21.7:
  * update rel notes
  * update deps
  * add minio bucket support
  * update ccnp/cnp checks
  * fix #414 #413
  * add info sub cmd
  * Bump k8s.io/cli-runtime from 0.32.0 to 0.32.1
  * Bump golang.org/x/net from 0.33.0 to 0.34.0
  * Add new codes to documentation
  * Bump github.com/cilium/cilium from 1.16.4 to 1.16.6
  * Bump golangci/golangci-lint-action
  * Bump github.com/prometheus/common from 0.60.1 to 0.62.0
  * Bump k8s.io/api from 0.32.0 to 0.32.1
  * Bump alpine from 3.21.0 to 3.21.2
  * Bump golang.org/x/net from 0.31.0 to 0.33.0
  * Bump sigs.k8s.io/gateway-api from 1.2.0 to 1.2.1
* Tue Dec 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.21.6:
  * deps
  * deps
  * update deps
  * rel v0.21.6
  * fix #267,#200,#168
  * fix #370,#356,#337,#301
  * clean up
  * clean up cilium netpols
  * update deps
  * Bump k8s.io/cli-runtime from 0.31.1 to 0.32.0
  * Bump k8s.io/metrics from 0.31.1 to 0.32.0
  * Bump k8s.io/cli-runtime from 0.31.1 to 0.32.0
  * Bump k8s.io/metrics from 0.31.1 to 0.32.0
  * Bump k8s.io/client-go from 0.31.1 to 0.32.0
  * Bump github.com/cilium/cilium from 1.16.3 to 1.16.5
  * Bump actions/setup-go from 5.1.0 to 5.2.0
  * Bump alpine from 3.20.3 to 3.21.0
  * Bump golangci/golangci-lint-action
  * Bump sigs.k8s.io/gateway-api from 1.1.0 to 1.2.0
  * Bump github.com/prometheus/client_golang from 1.20.0 to 1.20.5
  * Bump github.com/prometheus/common from 0.59.1 to 0.60.1
  * Bump actions/checkout from 4.1.7 to 4.2.2
  * Bump rajatjindal/krew-release-bot from 0.0.46 to 0.0.47
  * Bump golangci/golangci-lint-action
  * Bump golang.org/x/net from 0.28.0 to 0.31.0
  * Add detection of projected secrets & config maps
  * Bump actions/setup-go from 5.0.2 to 5.1.0
  * fix linter service port check for native sidecars
  * fix path to copyright file for nfpms
  * Bump github.com/cilium/cilium from 1.16.1 to 1.16.3
  * feat: Add the MIME content type to s3 uploads
* Sun Sep 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.21.5:
  * bump release
  * fix typo
  * ClusterRole: add aggregationRule support
  * Bump github.com/aws/aws-sdk-go from 1.35.21 to 1.55.5
  * Bump actions/setup-go from 4.1.0 to 5.0.2
  * Bump alpine from 3.19.1 to 3.20.3
  * Bump golang.org/x/text from 0.16.0 to 0.18.0
  * Bump github.com/fvbommel/sortorder from 1.0.1 to 1.1.0
  * Bump github.com/rs/zerolog from 1.18.0 to 1.33.0
  * Bump github.com/prometheus/common from 0.48.0 to 0.59.1
  * Bump golang from 1.21-alpine3.19 to 1.23-alpine3.19
  * Bump golangci/golangci-lint-action
  * Bump actions/checkout from 4.1.1 to 4.1.7
  * rel notes
  * fix #316
  * fix #314
  * update deps
  * add error codes link
  * by cluster/namespace
  * add avg by cluster
  * dashboard update
  * deps: bump prometheus common dep and use new syntax
  * Update README.md
  * feat(ci): Activate dependabot
  * Fix #302
  * bump alpine version to 3.19.1
  * cross-platform support
* Fri Mar 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.21.3:
  Resolved Issues
  * #298 Popeye showing errors for Complete cronjobs (with
    feelings!)
* Fri Mar 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.21.2:
  Resolved Issues:
  * #298 Popeye showing errors for Complete cronjobs
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.21.1:
  * [Rel] release v0.21.1
  * [Maint] add ns info to cid
  * [Bug] Fix #296
  * Rel v0.21.0
* Fri Mar 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.21.0:
  * Rel v0.21.0
  * [Maint] cleanup
  * init cilium res
  * [Maint] bump k8s rev
  * Need the indent command
  * Didn't match currently available releases
  * release v0.20.5
  * [Bug] Fix #290, #289
  * [Maint] semver pkg change
  * rel v0.20.4
  * [Bug] Fix #286
  * [Maint] Release notes
  * [Bug] Fix #284
  * rel notes
  * [Bug] Fix #280
  * release v0.20.1
  * log server info err
* Fri Mar 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.5:
  * release v0.20.5
  * [Bug] Fix #290, #289
  * [Maint] semver pkg change
  * [Maint] semver pkg change
  * rel v0.20.4
  * [Bug] Fix #286
* Fri Mar 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.4:
  * rel v0.20.4
  * [Bug] Fix #286
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.3:
  * [Maint] Release notes
  * [Bug] Fix #284
* Tue Feb 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.2:
  * Resolved Issues
  - #280 No RunInfo in context
* Tue Feb 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.1:
  * release v0.20.1
  * log server info err
  * update gha rev
  * doc update
* Sun Feb 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.0:
  large update from 0.11.3, full changelog can be found here:
  https://github.com/derailed/popeye/releases/tag/v0.20.0
  * Resolved Issues
  - #265 additional/fine grained prometheus metrics
  - #237 Support multiple outputs at once
  - #235 --lint level does not affect html output
  - #232 Metrics get overridden when using the same Pushgateway
    for multiple k8s clusters
  - #231 wrong warning: [POP-107] No resource limits defined
  - #230 APIs: metrics.k8s.io/v1beta1: the server is currently
    unable to handle the request
  - #214 [POP-1100] No pods match service selector - should not
    be detected for ExternalName service type
  - #213 Ingress extensions/v1beta1 deprecated (and deleted in
    k8s v1.22) is not detected ONLY in kube-metriques namespace
  - #212 Ingress networking.k8s.io/v1beta1 deprecated since k8s
    v1.19 and deleted in k8s v1.22, is not detected ONLY in
    specific namespace name as kube-metriques
  - #209 POP-403 - PodSecurityPolicy (PSP) k8s v1.21 deprecation
  - k8s v1.25 deletion - not detected
  - #202 False positive on NetworkPolicy using a catch all
    namespaceSelector
  - #163 popeye 0.9.0 with K8S 1.21.0 bug on PodDisruptionBudget
  - Wrong default API
  - #125 info/error/warning messages to the metrics sent to
    prometheus
  - #97 Add support for explicitly sanitizing jobs to popeye
  - #59 StatefulSet incorrectly determines apiVersio
* Sat Feb  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.3:
  * fix docker build
  * Added vulnerability fixes for Alpine Linux OS
  * Fix incorrect spelling
* Thu Dec 21 2023 opensuse_buildservice@ojkastl.de
- Update to version 0.11.2:
  * Update release deps
  * Maintenance release v0.11.2
  * Bump golang.org/x/net from 0.3.1-0.20221206200815-1e63c2f08a10
    to 0.7.0
  * fix typo in README.md
  * chore: remove refs to deprecated io/ioutil
  * fix typo in README.md
  * fix: check metrics before version in cluster sanitizer
  * fix: call AddErr() when nodes list fails
  * fix: call AddErr() when namespaces list fails
  * fix: call AddErr() when clusterrolebindings list fails
  * fix: call AddErr() when clusterroles list fails
  * fix: call AddErr() when clusterroles list fails
  * fix: call AddErr() when clusterrolebindings list fails
  * feat: update POP-402 message
  * feat: check metrics server in cluster sanitizer
  * Bump golang.org/x/net from 0.3.1-0.20221206200815-1e63c2f08a10
    to 0.7.0
  * Fix README fred* namespaces exclusion
* Tue Feb 21 2023 kastl@b1-systems.de
- Update to version 0.11.1:
  * fix #245
  * deprecated cronjob api
* Mon Feb 13 2023 kastl@b1-systems.de
- Update to version 0.11.0:
  * Release v0.11.0
  * Add check for pods that are managed by multiple pdbs
  * Update README.md
  * invalid value for --force-exit-zero
  * add a non-root user in docker image
  * optimize README documents
  * 📦 Add arm64 Darwin releases to krew-index
  * Add go install option to readme
  * Fixing CVE issue for client_golang 1.11.0 to 1.12.2
  * Fixing CVE issue for client_golang 1.11.0 to 1.12.1. Reverting from 1.12.2
  * Fixing CVE issue for client_golang 1.11.0 to 1.12.2
  * Add check for pods that are managed by multiple pdbs
  * fix RBAC rules in README.md
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.10.1:
  * fix issue with 2x pdb
  * fix docker build
* Thu Apr 14 2022 kastl@b1-systems.de
- Update to version 0.10.0:
  * update rel notes
  * update docs
  * fix: remove useless if/then
  * bump k8s version
  * fix: s3-endpoint flag description
  * Fix HPA API version derailed#207
  * feat: add other S3 object storage compatible support
  * feat: add GitPod for better UX for contributors
  * Fixes #211 (but might break backward compatilbility)
  * Update codes.md
  * Update codes.yml
  * Sets default registry as a constant. Only sanitizes registries if a registry list is provided.
  * Adds rule 113 which makes possible to add a list of allowed registries to pull images from. Otherwise, all images are allowed.
- BuildRequire go1.17
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.8:
  * NOTE: Fix'n brew deprecation warnings
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.7:
  * Issue #190 Popeye docker image tag 0.9.6 not available on quay.io
  * Issue #163 popeye 0.9.0 with K8S 1.21.0 bug on PodDisruptionBudget - Wrong default API. With Feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.6:
  * Issue #188 Can't run Popeye: No resource meta found for networking.k8s.io/v1/ingresses. With Feelings!
  * Issue #178 Custom handling of client-go/rest warnings. Sending to logger instead
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.5:
  * Issue #163 popeye 0.9.0 with K8S 1.21.0 bug on PodDisruptionBudget - Wrong default API - With Feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.4:
  * Issue #163 popeye 0.9.0 with K8S 1.21.0 bug on PodDisruptionBudget - Wrong default API
  * Issue #712 [POP-712] Found only one master node not flag on the right node
  * Issue #181 [POP-404] Deprecation check failed
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.3:
  * Issue #170 Can't run popeye when kubernetes has networking.k8s.io/v1/ingresses
  * PR #1102 Load codes with embed:fs and fix code 1102 format. Big Thanks to GoodWine for this excellent PR!!
* Wed May 26 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of package popeye
